@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2005, 2008
+ * Copyright (c) 1999-2005, 2008, 2010
  *	Todd C. Miller <Todd.Miller@courtesan.com>
  *
  * Permission to use, copy, modify, and distribute this software for any
@@ -52,6 +52,7 @@ struct sudo_defs_types {
     union {
 	int flag;
 	int ival;
+	double fval;
 	enum def_tupple tuple;
 	char *str;
 	mode_t mode;
@@ -61,7 +62,7 @@ struct sudo_defs_types {
 
 /*
  * Four types of defaults: strings, integers, and flags.
- * Also, T_INT or T_STR may be ANDed with T_BOOL to indicate that
+ * Also, T_INT, T_FLOAT or T_STR may be ANDed with T_BOOL to indicate that
  * a value is not required.  Flags are boolean by nature...
  */
 #undef T_INT
@@ -82,6 +83,8 @@ struct sudo_defs_types {
 #define T_LOGPRI	0x008
 #undef T_TUPLE
 #define T_TUPLE		0x009
+#undef T_FLOAT
+#define T_FLOAT		0x010
 #undef T_MASK
 #define T_MASK		0x0FF
 #undef T_BOOL
@@ -102,10 +105,11 @@ struct sudo_defs_types {
 /*
  * Prototypes
  */
-void dump_default	__P((void));
 int set_default		__P((char *, char *, int));
-void init_defaults	__P((void));
 int update_defaults	__P((int));
+void dump_default	__P((void));
+void dump_defaults	__P((void));
+void init_defaults	__P((void));
 void list_options	__P((void));
 
 extern struct sudo_defs_types sudo_defs_table[];
