@@ -287,17 +287,25 @@ perform_io(fdsr, fdsw, cstat)
 		n = read(iob->rfd, iob->buf + iob->len,
 		    sizeof(iob->buf) - iob->len);
 	    } while (n == -1 && errno == EINTR);
-	    if (n == -1) {
-		if (errno != EAGAIN)
+	    switch (n) {
+		case -1:
+		    if (errno == EAGAIN)
+			break;
+		    if (errno != ENXIO && errno != EBADF) {
+			errors++;
+			break;
+		    }
+		    /* FALLTHROUGH */
+		case 0:
+		    /* got EOF or pty has gone away */
+		    safe_close(iob->rfd);
+		    iob->rfd = -1;
+		    break;
+		default:
+		    if (!iob->action(iob->buf + iob->len, n))
+			terminate_child(child, TRUE);
+		    iob->len += n;
 		    break;
-	    } else if (n == 0) {
-		/* got EOF */
-		safe_close(iob->rfd);
-		iob->rfd = -1;
-	    } else {
-		if (!iob->action(iob->buf + iob->len, n))
-		    terminate_child(child, TRUE);
-		iob->len += n;
 	    }
 	}
 	if (iob->wfd != -1 && FD_ISSET(iob->wfd, fdsw)) {
@@ -306,8 +314,8 @@ perform_io(fdsr, fdsw, cstat)
 		    iob->len - iob->off);
 	    } while (n == -1 && errno == EINTR);
 	    if (n == -1) {
-		if (errno == EPIPE) {
-		    /* other end of pipe closed */
+		if (errno == EPIPE || errno == ENXIO || errno == EBADF) {
+		    /* other end of pipe closed or pty revoked */
 		    if (iob->rfd != -1) {
 			safe_close(iob->rfd);
 			iob->rfd = -1;
@@ -441,7 +449,7 @@ fork_pty(path, argv, envp, sv, rbac_enabled, maxfd)
 	/* child */
 	close(sv[0]);
 	fcntl(sv[1], F_SETFD, FD_CLOEXEC);
-	if (exec_setup(PERM_DOWAIT, rbac_enabled, slavename, io_fds[SFD_SLAVE]) == TRUE) {
+	if (exec_setup(rbac_enabled, slavename, io_fds[SFD_SLAVE]) == TRUE) {
 	    /* Close the other end of the stdin/stdout/stderr pipes and exec. */
 	    if (io_pipe[STDIN_FILENO][1])
 		close(io_pipe[STDIN_FILENO][1]);
@@ -514,7 +522,7 @@ pty_close(cstat)
     if (cstat->type == CMD_WSTATUS && WIFSIGNALED(cstat->val)) {
 	int signo = WTERMSIG(cstat->val);
 	if (signo && signo != SIGINT && signo != SIGPIPE) {
-	    char *reason = strsignal(signo);
+	    const char *reason = strsignal(signo);
 	    n = io_fds[SFD_USERTTY] != -1 ?
 		io_fds[SFD_USERTTY] : STDOUT_FILENO;
 	    write(n, reason, strlen(reason));
@@ -669,7 +677,7 @@ handle_sigchld(backchannel, cstat)
  * parent and relays signals from the parent to the command.
  * Returns an error if fork(2) fails, else calls _exit(2).
  */
-int
+static int
 exec_monitor(path, argv, envp, backchannel, rbac)
     const char *path;
     char *argv[];
