@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007 Todd C. Miller <Todd.Miller@courtesan.com>
+ * Copyright (c) 2007, 2010 Todd C. Miller <Todd.Miller@courtesan.com>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -14,8 +14,6 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
  * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * $Sudo: lbuf.h,v 1.2 2007/08/22 22:31:07 millert Exp $"
  */
 
 #ifndef _SUDO_LBUF_H
@@ -25,17 +23,20 @@
  * Line buffer struct.
  */
 struct lbuf {
+    int (*output)__P((const char *));
     char *buf;
-    int continuation;
+    const char *continuation;
     int indent;
     int len;
     int size;
+    int cols;
 };
 
-void lbuf_init		__P((struct lbuf *, char *, int, int));
-void lbuf_destroy	__P((struct lbuf *));
+int get_ttycols		__P((void));
 void lbuf_append	__P((struct lbuf *, ...));
 void lbuf_append_quoted	__P((struct lbuf *, const char *, ...));
+void lbuf_destroy	__P((struct lbuf *));
+void lbuf_init		__P((struct lbuf *, int (*)(const char *), int, const char *));
 void lbuf_print		__P((struct lbuf *));
 
 #endif /* _SUDO_LBUF_H */
