@@ -431,7 +431,7 @@ send_mail(fmt, va_alist)
 #ifndef NO_ROOT_MAILER
     static char *root_envp[] = {
 	"HOME=/",
-	"PATH=/usr/bin:/bin",
+	"PATH=/usr/bin:/bin:/usr/sbin:/sbin",
 	"LOGNAME=root",
 	"USERNAME=root",
 	"USER=root",
@@ -517,7 +517,7 @@ send_mail(fmt, va_alist)
 
 		/* Child, set stdin to output side of the pipe */
 		if (pfd[0] != STDIN_FILENO) {
-		    if (dup2(pfd[0], STDIN_FILENO) != -1) {
+		    if (dup2(pfd[0], STDIN_FILENO) == -1) {
 			mysyslog(LOG_ERR, "cannot dup stdin: %m");
 			_exit(127);
 		    }
