@@ -13,8 +13,6 @@
  * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
- *
- * $Sudo: logging.h,v 1.15 2009/05/25 12:02:41 millert Exp $
  */
 
 #ifndef _LOGGING_H
@@ -49,8 +47,8 @@
 # define MAXSYSLOGLEN		960
 #endif
 
-void audit_success		__P((char **));
-void audit_failure		__P((char **, char const * const, ...));
+void audit_success		__P((char *[]));
+void audit_failure		__P((char *[], char const * const, ...));
 void log_allowed		__P((int));
 void log_denial			__P((int, int));
 void log_error			__P((int flags, const char *fmt, ...))
