@@ -47,6 +47,10 @@
 #ifdef HAVE_LOGIN_CAP_H
 # include <login_cap.h>
 #endif
+#ifdef HAVE_PROJECT_H
+# include <project.h>
+# include <sys/task.h>
+#endif
 
 #include "sudo.h"
 
@@ -59,7 +63,7 @@
 /*
  * Prototypes
  */
-static void runas_setup		__P((int));
+static void runas_setup		__P((void));
 static void runas_setgroups	__P((void));
 static void restore_groups	__P((void));
 
@@ -77,10 +81,9 @@ set_perms(perm)
     int perm;
 {
     const char *errstr;
-    int noexit, dowait;
+    int noexit;
 
     noexit = ISSET(perm, PERM_NOEXIT);
-    dowait = ISSET(perm, PERM_DOWAIT);
     CLR(perm, PERM_MASK);
 
     if (perm == current_perm)
@@ -127,7 +130,7 @@ set_perms(perm)
 
 	case PERM_FULL_RUNAS:
 				/* headed for exec(), assume euid == ROOT_UID */
-				runas_setup(dowait);
+				runas_setup();
 				if (setresuid(def_stay_setuid ?
 				    user_uid : runas_pw->pw_uid,
 				    runas_pw->pw_uid, runas_pw->pw_uid)) {
@@ -192,10 +195,9 @@ set_perms(perm)
     int perm;
 {
     const char *errstr;
-    int noexit, dowait;
+    int noexit;
 
     noexit = ISSET(perm, PERM_NOEXIT);
-    dowait = ISSET(perm, PERM_DOWAIT);
     CLR(perm, PERM_MASK);
 
     if (perm == current_perm)
@@ -246,7 +248,7 @@ set_perms(perm)
 
 	case PERM_FULL_RUNAS:
 				/* headed for exec(), assume euid == ROOT_UID */
-				runas_setup(dowait);
+				runas_setup();
 				if (setreuid(def_stay_setuid ? user_uid :
 				    runas_pw->pw_uid, runas_pw->pw_uid)) {
 				    errstr = "unable to change to runas uid";
@@ -308,10 +310,9 @@ set_perms(perm)
     int perm;
 {
     const char *errstr;
-    int noexit, dowait;
+    int noexit;
 
     noexit = ISSET(perm, PERM_NOEXIT);
-    dowait = ISSET(perm, PERM_DOWAIT);
     CLR(perm, PERM_MASK);
 
     if (perm == current_perm)
@@ -368,7 +369,7 @@ set_perms(perm)
 
 	case PERM_FULL_RUNAS:
 				/* headed for exec() */
-				runas_setup(dowait);
+				runas_setup();
 				if (setuid(runas_pw->pw_uid)) {
 				    errstr = "unable to change to runas uid";
 				    goto bad;
@@ -428,10 +429,9 @@ set_perms(perm)
     int perm;
 {
     const char *errstr;
-    int noexit, dowait;
+    int noexit;
 
     noexit = ISSET(perm, PERM_NOEXIT);
-    dowait = ISSET(perm, PERM_DOWAIT);
     CLR(perm, PERM_MASK);
 
     if (perm == current_perm)
@@ -456,7 +456,7 @@ set_perms(perm)
 			      	break;
 				
 	case PERM_FULL_RUNAS:
-				runas_setup(dowait);
+				runas_setup();
 				if (setuid(runas_pw->pw_uid)) {
 				    errstr = "unable to change to runas uid";
 				    goto bad;
@@ -492,7 +492,8 @@ runas_setgroups()
 # ifdef HAVE_GETGROUPS
     static GETGROUPS_T *groups;
 # endif
-    struct passwd *pw;
+    static struct passwd *pw;
+    struct passwd *opw = pw;
 
     if (def_preserve_groups)
 	return;
@@ -500,14 +501,18 @@ runas_setgroups()
     /*
      * Use stashed copy of runas groups if available, else initgroups and stash.
      */
-    if (ngroups == -1) {
-	pw = runas_pw ? runas_pw : sudo_user.pw;
+    pw = runas_pw ? runas_pw : sudo_user.pw;
+    if (pw != opw) {
 # ifdef HAVE_SETAUTHDB
 	aix_setauthdb(pw->pw_name);
 # endif
 	if (initgroups(pw->pw_name, pw->pw_gid) < 0)
 	    log_error(USE_ERRNO|MSG_ONLY, "can't set runas group vector");
 # ifdef HAVE_GETGROUPS
+	if (groups) {
+	    efree(groups);
+	    groups = NULL;
+	}
 	if ((ngroups = getgroups(0, NULL)) > 0) {
 	    groups = emalloc2(ngroups, sizeof(GETGROUPS_T));
 	    if (getgroups(ngroups, groups) < 0)
@@ -546,9 +551,71 @@ restore_groups()
 
 #endif /* HAVE_INITGROUPS */
 
+#ifdef HAVE_PROJECT_H
 static void
-runas_setup(dowait)
-    int dowait;
+set_project(pw)
+    struct passwd *pw;
+{
+    struct project proj;
+    char buf[PROJECT_BUFSZ];
+    int errval;
+
+    /*
+     * Collect the default project for the user and settaskid
+     */
+    setprojent();
+    if (getdefaultproj(pw->pw_name, &proj, buf, sizeof(buf)) != NULL) {
+	errval = setproject(proj.pj_name, pw->pw_name, TASK_NORMAL);
+	switch(errval) {
+	case 0:
+	    break;
+	case SETPROJ_ERR_TASK:
+	    switch (errno) {
+	    case EAGAIN:
+		warningx("resource control limit has been reached");
+		break;
+	    case ESRCH:
+		warningx("user \"%s\" is not a member of project \"%s\"",
+		    pw->pw_name, proj.pj_name);
+		break;
+	    case EACCES:
+		warningx("the invoking task is final");
+		break;
+	    default:
+		warningx("could not join project \"%s\"", proj.pj_name);
+	    }
+	case SETPROJ_ERR_POOL:
+	    switch (errno) {
+	    case EACCES:
+		warningx("no resource pool accepting default bindings "
+		    "exists for project \"%s\"", proj.pj_name);
+		break;
+	    case ESRCH:
+		warningx("specified resource pool does not exist for "
+		    "project \"%s\"", proj.pj_name);
+		break;
+	    default:
+		warningx("could not bind to default resource pool for "
+		    "project \"%s\"", proj.pj_name);
+	    }
+	    break;
+	default:
+	    if (errval <= 0) {
+		warningx("setproject failed for project \"%s\"", proj.pj_name);
+	    } else {
+		warningx("warning, resource control assignment failed for "
+		    "project \"%s\"", proj.pj_name);
+	    }
+	}
+    } else {
+	warning("getdefaultproj");
+    }
+    endprojent();
+}
+#endif /* HAVE_PROJECT_H */
+
+static void
+runas_setup()
 {
     gid_t gid;
 #ifdef HAVE_LOGIN_CAP_H
@@ -558,13 +625,14 @@ runas_setup(dowait)
 
     if (runas_pw->pw_name != NULL) {
 	gid = runas_gr ? runas_gr->gr_gid : runas_pw->pw_gid;
+#ifdef HAVE_PROJECT_H
+	set_project(runas_pw);
+#endif
 #ifdef HAVE_GETUSERATTR
 	aix_prep_user(runas_pw->pw_name, user_ttypath);
 #endif
 #ifdef HAVE_PAM
 	pam_begin_session(runas_pw);
-	if (!dowait)
-	    pam_end_session();
 #endif /* HAVE_PAM */
 
 #ifdef HAVE_LOGIN_CAP_H
