@@ -148,7 +148,6 @@ struct command_status {
 #define PERM_FULL_RUNAS          0x05
 #define PERM_TIMESTAMP           0x06
 #define PERM_NOEXIT              0x10 /* flag */
-#define PERM_DOWAIT              0x20 /* flag */
 #define PERM_MASK                0xf0
 
 /*
@@ -230,7 +229,7 @@ void env_init		__P((int lazy));
 void init_envtables	__P((void));
 void insert_env_vars	__P((struct list_member *));
 void read_env_file	__P((const char *, int));
-void rebuild_env	__P((int, int));
+void rebuild_env	__P((int));
 void validate_env_vars	__P((struct list_member *));
 
 /* exec.c */
@@ -314,7 +313,7 @@ int set_perms		__P((int));
 
 /* sudo.c */
 FILE *open_sudoers	__P((const char *, int, int *));
-int exec_setup		__P((int, int, const char *, int));
+int exec_setup		__P((int, const char *, int));
 void cleanup		__P((int));
 void set_fqdn		__P((void));
 
@@ -355,6 +354,7 @@ extern struct passwd *auth_pw, *list_pw;
 
 extern int tgetpass_flags;
 extern int long_list;
+extern int sudo_mode;
 extern uid_t timestamp_uid;
 /* XXX - conflicts with the one in visudo */
 int run_command __P((const char *path, char *argv[], char *envp[], uid_t uid, int dowait));
