@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996, 1998-2005, 2007-2009
+ * Copyright (c) 1996, 1998-2005, 2007-2010
  *	Todd C. Miller <Todd.Miller@courtesan.com>
  *
  * Permission to use, copy, modify, and distribute this software for any
@@ -41,11 +41,10 @@
 #  include <memory.h>
 # endif
 # include <string.h>
-#else
-# ifdef HAVE_STRINGS_H
-#  include <strings.h>
-# endif
 #endif /* HAVE_STRING_H */
+#ifdef HAVE_STRINGS_H
+# include <strings.h>
+#endif /* HAVE_STRINGS_H */
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif /* HAVE_UNISTD_H */
@@ -56,20 +55,12 @@
 
 #include "sudo.h"
 
-#ifndef lint
-__unused static const char rcsid[] = "$Sudo: tgetpass.c,v 1.131 2009/05/25 12:02:42 millert Exp $";
-#endif /* lint */
-
-static volatile sig_atomic_t signo;
+static volatile sig_atomic_t signo[NSIG];
 
 static void handler __P((int));
 static char *getln __P((int, char *, size_t, int));
 static char *sudo_askpass __P((const char *));
 
-extern int term_restore __P((int));
-extern int term_noecho __P((int));
-extern int term_raw __P((int));
-
 /*
  * Like getpass(3) but with timeout and echo flags.
  */
@@ -80,10 +71,10 @@ tgetpass(prompt, timeout, flags)
     int flags;
 {
     sigaction_t sa, savealrm, saveint, savehup, savequit, saveterm;
-    sigaction_t savetstp, savettin, savettou;
+    sigaction_t savetstp, savettin, savettou, savepipe;
     char *pass;
     static char buf[SUDO_PASS_MAX + 1];
-    int input, output, save_errno, neednl;;
+    int i, input, output, save_errno, neednl = 0, need_restart;
 
     (void) fflush(stdout);
 
@@ -92,9 +83,11 @@ tgetpass(prompt, timeout, flags)
 	return(sudo_askpass(prompt));
 
 restart:
-    signo = 0;
+    for (i = 0; i < NSIG; i++)
+	signo[i] = 0;
     pass = NULL;
     save_errno = 0;
+    need_restart = 0;
     /* Open /dev/tty for reading/writing if possible else use stdin/stderr. */
     if (ISSET(flags, TGP_STDIN) ||
 	(input = output = open(_PATH_TTY, O_RDWR|O_NOCTTY)) == -1) {
@@ -102,6 +95,17 @@ restart:
 	output = STDERR_FILENO;
     }
 
+    /*
+     * If we are using a tty but are not the foreground pgrp this will
+     * generate SIGTTOU, so do it *before* installing the signal handlers.
+     */
+    if (!ISSET(flags, TGP_ECHO)) {
+	if (def_pwfeedback)
+	    neednl = term_cbreak(input);
+	else
+	    neednl = term_noecho(input);
+    }
+
     /*
      * Catch signals that would otherwise cause the user to end
      * up with echo turned off in the shell.
@@ -119,28 +123,25 @@ restart:
     (void) sigaction(SIGTTIN, &sa, &savettin);
     (void) sigaction(SIGTTOU, &sa, &savettou);
 
-    if (def_pwfeedback)
-	neednl = term_raw(input);
-    else
-	neednl = term_noecho(input);
+    /* Ignore SIGPIPE in case stdin is a pipe and TGP_STDIN is set */
+    sa.sa_handler = SIG_IGN;
+    (void) sigaction(SIGPIPE, &sa, &savepipe);
 
-    /* No output if we are already backgrounded. */
-    if (signo != SIGTTOU && signo != SIGTTIN) {
-	if (prompt)
-	    (void) write(output, prompt, strlen(prompt));
+    if (prompt)
+	(void) write(output, prompt, strlen(prompt));
 
-	if (timeout > 0)
-	    alarm(timeout);
-	pass = getln(input, buf, sizeof(buf), def_pwfeedback);
-	alarm(0);
-	save_errno = errno;
+    if (timeout > 0)
+	alarm(timeout);
+    pass = getln(input, buf, sizeof(buf), def_pwfeedback);
+    alarm(0);
+    save_errno = errno;
 
-	if (neednl)
-	    (void) write(output, "\n", 1);
-    }
+    if (neednl || pass == NULL)
+	(void) write(output, "\n", 1);
 
     /* Restore old tty settings and signals. */
-    term_restore(input);
+    if (!ISSET(flags, TGP_ECHO))
+	term_restore(input, 1);
     (void) sigaction(SIGALRM, &savealrm, NULL);
     (void) sigaction(SIGINT, &saveint, NULL);
     (void) sigaction(SIGHUP, &savehup, NULL);
@@ -149,6 +150,7 @@ restart:
     (void) sigaction(SIGTSTP, &savetstp, NULL);
     (void) sigaction(SIGTTIN, &savettin, NULL);
     (void) sigaction(SIGTTOU, &savettou, NULL);
+    (void) sigaction(SIGTTOU, &savepipe, NULL);
     if (input != STDIN_FILENO)
 	(void) close(input);
 
@@ -156,15 +158,20 @@ restart:
      * If we were interrupted by a signal, resend it to ourselves
      * now that we have restored the signal handlers.
      */
-    if (signo) {
-	kill(getpid(), signo);
-	switch (signo) {
-	    case SIGTSTP:
-	    case SIGTTIN:
-	    case SIGTTOU:
-		goto restart;
+    for (i = 0; i < NSIG; i++) {
+	if (signo[i]) {
+	    kill(getpid(), i);
+	    switch (i) {
+		case SIGTSTP:
+		case SIGTTIN:
+		case SIGTTOU:
+		    need_restart = 1;
+		    break;
+	    }
 	}
     }
+    if (need_restart)
+	goto restart;
 
     if (save_errno)
 	errno = save_errno;
@@ -191,6 +198,10 @@ sudo_askpass(prompt)
 
     if (pid == 0) {
 	/* child, point stdout to output side of the pipe and exec askpass */
+	if (dup2(pfd[1], STDOUT_FILENO) == -1) {
+	    warning("dup2");
+	    _exit(255);
+	}
 	(void) dup2(pfd[1], STDOUT_FILENO);
 	set_perms(PERM_FULL_USER);
 	closefrom(STDERR_FILENO + 1);
@@ -202,7 +213,7 @@ sudo_askpass(prompt)
     /* Ignore SIGPIPE in case child exits prematurely */
     zero_bytes(&sa, sizeof(sa));
     sigemptyset(&sa.sa_mask);
-    sa.sa_flags = 0;
+    sa.sa_flags = SA_INTERRUPT;
     sa.sa_handler = SIG_IGN;
     (void) sigaction(SIGPIPE, &sa, &saved_sa_pipe);
 
@@ -275,7 +286,7 @@ handler(s)
     int s;
 {
     if (s != SIGALRM)
-	signo = s;
+	signo[s] = 1;
 }
 
 int
